Installation — Track Analyzer 0.1a documentation

# Installation

## Track Analyzer installation

- Install Python 3.7: download miniconda 3.7: https://docs.conda.io/en/latest/miniconda.html

- Open a Terminal (Mac & Linux) or open an Anaconda powershell (Windows)

- Create environment: run conda create -n pyTA python=3.7

- Activate environment (to be run every time you open a new terminal): run conda activate pyTA

Run

::

  pip install…

### Archive overview

- doc => the documentation in html and pdf

- example => synthetic data examples are stored in the example folder. Each example contains a params.csv file containing for each track the “true” values.

- track_analyzer => the track analyzer python library

- setup.py => the installation script

- requirements.txt => the python dependencies

- COPYING => the licensing

- README.md => brief overview

- analyze_traj_gui.ipynb => the jupyter notebook used for the graphical interface

## Track Analyzer dependencies

Track Analyzer depends on several python packages that will be installed with the pip install:

- numpy

- matplotlib

- pandas

- scipy

- scikit-image

- seaborn

- jupyter

- joblib

- lmfit

- tifffile

- napari

- ipyfilechooser

- ipywidgets